@@ -6,12 +6,13 @@ grid.
 '''
 
 import json
+import warnings
 from typing import (Sequence, Optional, Union, Any, Dict,
                     List, Iterator)  # @UnusedImport
 
 import numpy as np
 
-from .base import FieldBase, DataFieldBase
+from .base import FieldBase, DataFieldBase, PlotReference, OptionalArrayLike
 from .scalar import ScalarField
 from ..grids.base import GridBase
 
@@ -22,7 +23,7 @@ class FieldCollection(FieldBase):
 
 
     def __init__(self, fields: Sequence[DataFieldBase],
-                 data=None,
+                 data: OptionalArrayLike = None,
                  copy_fields: bool = False,
                  label: Optional[str] = None):
         """ 
@@ -35,7 +36,8 @@ class FieldCollection(FieldBase):
             copy_fields (bool):
                 Flag determining whether the individual fields given in `fields`
                 are copied. 
-            label (str): Label of the field collection
+            label (str):
+                Label of the field collection
             
         Warning:
             If `data` is given and `copy_fields == False`, the data in the
@@ -67,7 +69,7 @@ class FieldCollection(FieldBase):
         for field in self.fields:
             if not isinstance(field, DataFieldBase):
                 raise RuntimeError('Individual fields must be of type '
-                                   'DataFieldBase. FieldCollections cannot be '
+                                   'DataFieldBase. Field collections cannot be '
                                    'nested')
             start = len(new_data)
             this_data = field._data_flat
@@ -78,15 +80,15 @@ class FieldCollection(FieldBase):
         # combine into one data field
         data_shape = (dof,) + grid.shape
         if data is None:
-            data = np.array(new_data, dtype=np.double)
+            data_arr = np.array(new_data, dtype=np.double)
         else:
-            data = np.asarray(data, dtype=np.double)
-            if data.shape != data_shape:
-                data = np.array(np.broadcast_to(data, data_shape))
-        assert data.shape == data_shape
+            data_arr = np.asarray(data, dtype=np.double)
+            if data_arr.shape != data_shape:
+                data_arr = np.array(np.broadcast_to(data_arr, data_shape))
+        assert data_arr.shape == data_shape
         
         # initialize the class
-        super().__init__(grid, data, label=label)        
+        super().__init__(grid, data_arr, label=label)        
             
         # link the data of the original fields back to self._data if they were
         # not copied
@@ -307,14 +309,16 @@ class FieldCollection(FieldBase):
         return results
     
     
-    def copy(self, data=None, label: str = None) -> 'FieldCollection':
+    def copy(self, data: OptionalArrayLike = None, label: str = None) \
+            -> 'FieldCollection':
         """ return a copy of the data, but not of the grid
         
         Args:
-            data (:class:`numpy.ndarray`, optional): Data values at the support
-                points of the grid that define the field. Note that the data is
-                not copied but used directly.
-            label (str, optional): Name of the copied field
+            data (:class:`numpy.ndarray`, optional):
+                Data values at the support points of the grid that define the
+                field. Note that the data is not copied but used directly.
+            label (str, optional):
+                Name of the copied field
         """
         if label is None:
             label = self.label
@@ -387,20 +391,28 @@ class FieldCollection(FieldBase):
             f_in.smooth(sigma=sigma, out=f_out)
              
         return out   
-         
+
         
-    def get_line_data(self, index: int = 0,  # type: ignore
-                      **kwargs) -> Dict[str, Any]:
+    def get_line_data(self,  # type: ignore
+                      index: int = 0,
+                      scalar: str = 'auto',
+                      extract: str = 'auto') -> Dict[str, Any]:
         r""" return data for a line plot of the field
         
         Args:
-            index (int): Index of the field whose data is returned
-            \**kwargs: Arguments forwarded to the `get_line_data` method
+            index (int):
+                Index of the field whose data is returned
+            scalar (str or int):
+                The method for extracting scalars as described in
+                :meth:`DataFieldBase.to_scalar`.
+            extract (str):
+                The method used for extracting the line data. See the docstring
+                of the grid method `get_line_data` to find supported values.
                 
         Returns:
             dict: Information useful for performing a line plot of the field
         """
-        return self[index].get_line_data(**kwargs)
+        return self[index].get_line_data(scalar=scalar, extract=extract)
     
     
     def get_image_data(self, index: int = 0, **kwargs) -> Dict[str, Any]:
@@ -414,114 +426,89 @@ class FieldCollection(FieldBase):
             dict: Information useful for plotting an image of the field
         """
         return self[index].get_image_data(**kwargs)
-    
-    
-    def plot_collection(self,
-                        title: Optional[str] = None,
-                        tight: bool = True,
-                        filename: str = None,
-                        show: bool = False,
-                        **kwargs):
-        r""" visualize all fields by plotting them next to each other
-        
-        Args:
-            title (str):
-                Title of the plot. If omitted, the title is chosen automatically
-                based on the label the data field.
-            tight (bool):
-                Whether to call :func:`matplotlib.pyplot.tight_layout`. This
-                affects the layout of all plot elements.
-            filename (str, optional):
-                If given, the plot is written to the specified file.
-            show (bool):
-                Whether to call :func:`matplotlib.pyplot.show`
-            \**kwargs:
-                Additional keyword arguments are passed to the method
-                plotting function of the individual fields.
-        """
-        import matplotlib.pyplot as plt
-        
-        # plot the individual panels
-        fig, axes = plt.subplots(1, len(self), figsize=(4 * len(self), 3))
-        for field, ax in zip(self.fields, axes):
-            field.plot(ax=ax, **kwargs)
-            
-        # set the title above all panels
-        fig.suptitle(self.label if title is None else title)
-            
-        # adjust layout
-        if tight:
-            fig.tight_layout()
-            
-        from ..visualization.plotting import finalize_plot
-        finalize_plot(fig, filename=filename, show=show)
-    
-    
-    def plot_line(self, **kwargs):
-        r""" visualize all fields using line plots
-        
-        Args:
-            \**kwargs:
-                Supported keyword arguments include `title` to set the title,
-                `tight` to adjust the layout, `filename` to write the image to a
-                file, and `show` to call :func:`matplotlib.pyplot.show`. These
-                are described in :meth:`~FieldCollection.plot_collection`.
-        """
-        self.plot_collection(kind='line', **kwargs)
-        
-        
-    def plot_vector(self, **kwargs):
-        r""" visualize all fields using vector plots
-        
-        Args:
-            \**kwargs:
-                Supported keyword arguments include `title` to set the title,
-                `tight` to adjust the layout, `filename` to write the image to a
-                file, and `show` to call :func:`matplotlib.pyplot.show`. These
-                are described in :meth:`~FieldCollection.plot_collection`.
-        """
-        self.plot_collection(kind='vector', **kwargs)
 
-    
-    def plot_image(self, quantities=None,
-                   title: Optional[str] = None,
-                   tight: bool = True,
-                   filename: str = None,
-                   show: bool = True,
-                   **kwargs):
-        r""" visualize all fields using density plots
+
+    def plot(self,
+             kind='auto',
+             title: str = None,
+             filename: str = None,
+             show: bool = True,
+             close_figure: bool = False,
+             tight: bool = True,
+             **kwargs) -> List[PlotReference]:
+        r""" visualize all the fields in the collection
         
         Args:
-            quantities:
-                Determines what exactly is plotted. See
-                :class:`~pde.visualization.plotting.ScalarfieldPlot` for details
+            kind (str):
+                Determines the visualizations. Supported values are `image`, 
+                `line`, `vector`, or `interactive`. Alternatively, `auto`
+                determines the best visualization based on each field itself.
             title (str):
-                Title of the plot. If omitted, the title is chosen automatically
-                based on the label the data field.
-            tight (bool):
-                Whether to call :func:`matplotlib.pyplot.tight_layout`. This
-                affects the layout of all plot elements.
+                Title of the plot. If omitted, the title is chosen
+                automatically based on the label the data field.
             filename (str, optional):
                 If given, the plot is written to the specified file.
             show (bool):
                 Flag setting whether :func:`matplotlib.pyplot.show` is called
+            close_figure (bool):
+                Flag setting whether the figure is closed (after it was shown)
+            tight (bool):
+                Whether to call :func:`matplotlib.pyplot.tight_layout`. This
+                affects the layout of all plot elements.
             \**kwargs:
-                Additional keyword arguments are passed to the plot methods of
-                the individual fields
+                All additional keyword arguments are forwarded to the actual
+                plotting functions.
+                
+        Returns:
+            list of :class:`PlotReference`: Instances that contain information
+            to update all the plots with new data later.
         """
-        if title is None:
-            title = self.label
+        import matplotlib.pyplot as plt
+        from ..visualization.contexts import disable_interactive
+        
+        # disable interactive plotting temporarily
+        with disable_interactive():
+            # create a plot with all the panels 
+            fig, axs = plt.subplots(1, len(self), figsize=(4 * len(self), 3))
             
-        # create the plot panels
-        from ..visualization.plotting import ScalarFieldPlot
-        plot = ScalarFieldPlot(self, quantities=quantities, title=title,
-                               tight=tight, show=show)
-        
-        # save plot to file if requested
-        if filename:
-            plot.fig.savefig(filename)
+            # plot all the elements into the respective axes 
+            reference = [field.plot(kind, ax=ax, show=False, **kwargs)
+                         for field, ax in zip(self.fields, axs)]
+                    
+                    
+            # adjust layout
+            if tight:
+                plt.tight_layout()
+                    
+            # finishing touches...            
+            if title is not None:
+                fig.suptitle(title)
+            if filename:
+                fig.savefig(filename)
+                
+        # decide what to do with the final plot
+        if show:
+            with warnings.catch_warnings():
+                warnings.simplefilter("ignore")
+                plt.show()
+        if close_figure:
+            plt.close(fig)        
+                
+        # return the references for all subplots
+        return reference
+    
+
+    def update_plot(self, reference: List[PlotReference]) -> None:
+        """ update a plot collection with the current field values
         
+        Args:
+            reference (list of :class:`PlotReference`):
+                All references of the plot to update
+        """
+        for field, ref in zip(self.fields, reference):
+            field.update_plot(ref)
         
+            
     def plot_interactive(self, scalar: str = 'auto', **kwargs):
         """ create an interactive plot of the field using :mod:`napari`
 
@@ -536,36 +523,3 @@ class FieldCollection(FieldBase):
                                  name=field.label,
                                  rgb=False,
                                  scale=self.grid.discretization)
-
-        
-    def plot(self, kind: str = 'auto', **kwargs):
-        r""" visualize the field collection
-        
-        Args:
-            kind (str):
-                Determines how to visualize the collection. Supported values are
-                `image`, `line`, `vector`, or `interactive`. Alternatively,
-                `auto` determines the best visualization based on each
-                individual field itself.
-            \**kwargs:
-                All additional keyword arguments are forwarded to the actual
-                plotting functions. They include the keyword arguments `title`
-                to set the title, `tight` to adjust the layout, `filename` to
-                write the image to a file, and `show` to call
-                :func:`matplotlib.pyplot.show`. These arguments are described in
-                :meth:`~FieldCollection.plot_collection`.
-        """
-        if kind == 'auto':
-            self.plot_collection(**kwargs)
-        elif kind == 'image':
-            self.plot_image(**kwargs)
-        elif kind == 'line':
-            self.plot_line(**kwargs)
-        elif kind == 'vector':
-            self.plot_vector(**kwargs)
-        elif kind == 'interactive':
-            self.plot_interactive(**kwargs)
-        else:
-            raise ValueError(f'Unsupported plot `{kind}`. Possible choices are '
-                             '`image`, `line`, `vector`, or `auto`.')
-    
