@@ -25,7 +25,7 @@ import sys
 import os.path
 import time
 from typing import (Callable, Optional, Union, IO, List, Any,  # @UnusedImport
-                    TYPE_CHECKING)
+                    Dict, TYPE_CHECKING)
 
 import numpy as np
 
@@ -33,7 +33,6 @@ from .base import TrackerBase, InfoDict, FinishedSimulation, Real
 from .intervals import IntervalData, RealtimeIntervals
 from ..fields.base import FieldBase
 from ..fields import FieldCollection
-from ..visualization.plotting import ScaleData
 from ..tools.parse_duration import parse_duration
 from ..tools.misc import get_progress_bar_class
 from ..tools.docstrings import fill_in_docstring
@@ -239,28 +238,26 @@ class PrintTracker(TrackerBase):
 
 
 class PlotTracker(TrackerBase):
-    """ Tracker that plots data on screen, to files, or writes a movie
-    
-    The plot tracker uses the 
-    :class:`~pde.visualization.plotting.ScalarFieldPlot` class to show fields
-    and field collections. Most options are thus forwarded to this class.
-    """
+    """ Tracker that plots data on screen, to files, or writes a movie """
      
     name = 'plot'
     
     @fill_in_docstring
     def __init__(self, interval: IntervalData = 1,
+                 title: str = '',
                  output_file: Optional[str] = None,
                  output_folder: Optional[str] = None,
                  movie_file: Optional[str] = None,
-                 quantities=None,
-                 scale: ScaleData = 'automatic',
-                 tight: bool = False,
-                 show: bool = True):
+                 show: bool = True,
+                 close_final: bool = False,
+                 plot_arguments: Dict[str, Any] = None):
         """
         Args:
             interval:
                 {ARG_TRACKER_INTERVAL}
+            title (str):
+                Text to show in the title. The current time point will be
+                appended to this text, so include a space for optimal results.
             output_file (str, optional):
                 Specifies a single image file, which is updated periodically, so
                 that the progress can be monitored (e.g. on a compute cluster)
@@ -270,24 +267,20 @@ class PlotTracker(TrackerBase):
             movie_file (str, optional):
                 Specifies a filename to which a movie of all the frames is
                 written after the simulation.
-            quantities:
-                {ARG_PLOT_QUANTITIES}
-            scale (str, float, tuple of float):
-                {ARG_PLOT_SCALE}
-            tight (bool):
-                Whether to call :func:`matplotlib.pyplot.tight_layout`. This
-                affects the layout of all plot elements.
             show (bool, optional):
                 Determines whether the plot is shown while the simulation is
                 running. If `False`, the files are created in the background.
+                This option can slow down a simulation severely.
+            plot_arguments (dict):
+                Extra arguments supplied to the plot call
         """
         super().__init__(interval=interval)
+        self.title = title
         self.output_file = output_file
         self.output_folder = output_folder
-        self.quantities = quantities
-        self.scale = scale
-        self.tight = tight
         self.show = show
+        self.close_final = close_final
+        self.plot_arguments = {} if plot_arguments is None else plot_arguments
         
         if movie_file is not None or output_folder is not None:
             from ..visualization.movies import Movie
@@ -310,16 +303,22 @@ class PlotTracker(TrackerBase):
         Returns:
             float: The first time the tracker needs to handle data
         """
-        from ..visualization.plotting import ScalarFieldPlot
+        # initialize the plotting context
+        from ..visualization.contexts import get_plotting_context
+        title = self.title + 'Initializing...'
+        self._context = get_plotting_context(title=title, show=self.show)
         
-        # initialize the plotting panels
-        self.plot = ScalarFieldPlot(field,
-                                    quantities=self.quantities,
-                                    scale=self.scale,
-                                    title='Initializing...',
-                                    tight=self.tight,
-                                    show=self.show)
-         
+        self.plot_arguments['show'] = False  # this is handled by the context
+        
+        # do the actual plotting
+        with self._context:
+            self._plot_reference = field.plot(**self.plot_arguments)
+
+        # determine whether this plot can be updated in the following
+        self._update_plot = (self._context.supports_update and 
+                             hasattr(field, 'update_plot') and
+                             self._plot_reference is not None)
+            
         return super().initialize(field, info=info)
         
          
@@ -332,11 +331,19 @@ class PlotTracker(TrackerBase):
             t (float):
                 The associated time
         """
-        self.plot.update(field, title=f'Time: {t:g}')
-        if self.output_file:
-            self.plot.fig.savefig(self.output_file)
+        self._context.title = f'{self.title}Time: {t:g}'
+        
+        # update the plot in the correct plotting context
+        with self._context:
+            if self._update_plot:
+                field.update_plot(reference=self._plot_reference)
+            else:
+                field.plot(**self.plot_arguments)
+                
+        if self.output_file and self._context.fig is not None:
+            self._context.fig.savefig(self.output_file)
         if self.movie:
-            self.movie.add_figure(self.plot.fig)
+            self.movie.add_figure(self._context.fig)
           
 
     def finalize(self, info: InfoDict = None) -> None:
@@ -354,8 +361,9 @@ class PlotTracker(TrackerBase):
                 self.movie.save()
             # finalize movie (e.g. delete temporary files)
             self.movie._end()
-        if not self.show:
-            del self.plot
+            
+        if not self.show or self.close_final:
+            self._context.close()
     
               
     
