@@ -2,9 +2,6 @@
 .. codeauthor:: David Zwicker <david.zwicker@ds.mpg.de>
 '''
 
-import os
-import tempfile
-
 from .. import plotting
 from ...grids import UnitGrid
 from ...fields import ScalarField, FieldCollection
@@ -14,26 +11,28 @@ from ...tools.misc import skipUnlessModule
 
 
 @skipUnlessModule("matplotlib")
-def test_scalar_field_plot():
+def test_scalar_field_plot(tmp_path):
     """ test ScalarFieldPlot class"""
+    path = tmp_path / "test_scalar_field_plot.png"
+            
     # create some data
     state = ScalarField.random_uniform(UnitGrid([16, 16]))
     for scale in [(0, 1), 1, 'automatic', 'symmetric', 'unity']:
         sfp = plotting.ScalarFieldPlot(state, scale=scale)
-        with tempfile.NamedTemporaryFile(suffix='.png') as fp:
-            sfp.savefig(fp.name)
-            assert os.stat(fp.name).st_size > 0
+        sfp.savefig(path)
+        assert path.stat().st_size > 0
 
     sfp = plotting.ScalarFieldPlot(state, quantities={'source': None})
-    with tempfile.NamedTemporaryFile(suffix='.png') as fp:
-        sfp.savefig(fp.name)
-        assert os.stat(fp.name).st_size > 0
+    sfp.savefig(path)
+    assert path.stat().st_size > 0
 
 
 
 @skipUnlessModule("matplotlib")
-def test_scalar_plot():
+def test_scalar_plot(tmp_path):
     """ test Simple simulation """
+    path = tmp_path / "test_scalar_plot.png"
+    
     # create some data
     state = ScalarField.random_uniform(UnitGrid([16, 16]), label='test')
     with get_memory_storage(state) as storage:
@@ -41,19 +40,17 @@ def test_scalar_plot():
         storage.append(state.data, 1)
     
     # check creating an overview image
-    with tempfile.NamedTemporaryFile(suffix='.png') as fp:
-        plotting.plot_magnitudes(storage, filename=fp.name)
-        assert os.stat(fp.name).st_size > 0
+    plotting.plot_magnitudes(storage, filename=path)
+    assert path.stat().st_size > 0
 
     # check creating an kymograph
-    with tempfile.NamedTemporaryFile(suffix='.png') as fp:
-        plotting.plot_kymograph(storage, filename=fp.name)
-        assert os.stat(fp.name).st_size > 0
+    plotting.plot_kymograph(storage, filename=path)
+    assert path.stat().st_size > 0
 
 
 
 @skipUnlessModule("matplotlib")
-def test_collection_plot():
+def test_collection_plot(tmp_path):
     """ test Simple simulation """
     # create some data
     field = FieldCollection([ScalarField(UnitGrid([8, 8]), label='first'),
@@ -61,7 +58,7 @@ def test_collection_plot():
     with get_memory_storage(field) as storage:
         storage.append(field.data)
     
-    with tempfile.NamedTemporaryFile(suffix='.png') as fp:
-        plotting.plot_magnitudes(storage, filename=fp.name)
-        assert os.stat(fp.name).st_size > 0
+    path = tmp_path / 'test_collection_plot.png'
+    plotting.plot_magnitudes(storage, filename=path)
+    assert path.stat().st_size > 0
 
